@@ -2,5 +2,7 @@ from cognite.experimental.data_classes.annotations import *
 from cognite.experimental.data_classes.assets import *
 from cognite.experimental.data_classes.contextualization import *
 from cognite.experimental.data_classes.functions import *
+from cognite.experimental.data_classes.integrationruns import *
+from cognite.experimental.data_classes.integrations import *
 from cognite.experimental.data_classes.relationships import *
 from cognite.experimental.data_classes.types import *
